@@ -4,6 +4,7 @@
 #include <R_ext/Utils.h>
 #include <R_ext/Rdynload.h>
 #include <R_ext/Visibility.h> 
+#include <omp.h>
 
 //Hash table
 
@@ -32,6 +33,7 @@ static const R_CallMethodDef R_CallDef[]={
  CALLDEF(C_engineTest,2),
  CALLDEF(C_getMi,2),
  CALLDEF(C_getNmi,2),
+ CALLDEF(C_setOmpThreads,1),
  CALLDEF(C_MI,3),
  CALLDEF(C_CMIM,3),
  CALLDEF(C_JMI,3),
